function [ output ] = pctile(x)
% [output] = pctile(x)
%   Returns a vector/matrix OUTPUT of the same size as X containing the
%   corresponding percentile values to each element of X.
%
%   If X is a matrix, it is treated as if it was a vector. Meaning that its
%   elements are all considered to be elements of a vector and the matrix
%   position is only a formatting issue.
% ------------------------------------------------------------------------
% EXAMPLES
% 
% a=[1 4 2 3 NaN 3 1 4 3 2];
% pctile(a)
% 
% a=[1 4 2 3 NaN; 3 1 4 3 2];
% pctile(a)
% ========================================================================
%                    Background Information
% ------------------------------------------------------------------------
%  Function to calculate percentiles of the elements of a vector.
%  
%    Stephanie Lackner                   Version 1
%    www.columbia.edu/~sl3382            June 5, 2014
%    sl3382@columbia.edu           
% ========================================================================

[m,n]=size(x);

%If it is a matrix, turn it into a vector
if m~=1
    if n~=1
        vector=reshape(x,m*n,1);
    else
        vector=x;
    end
else
    vector=x;
end

[temp, index]=sort(vector);
indexswitch=NaN(1,length(index));
for i=1:length(index)
    indexswitch(index(i))=i;
end
PercVector=indexswitch./sum(isnan(vector)==0);

%Correct NaNs
PercVector(isnan(vector))=NaN;

%Correct for same elements
for i=1:length(temp)-1
    k=0;
    while temp(i)==temp(i+1+k)
        k=k+1;
    end
    PercVector(index(i))=PercVector(index(i+k));
end

%If it was a matrix, turn it back to matrix
if m~=1
    if n~=1
        output=reshape(PercVector,m,n);
    else
        output=PercVector;
    end
else
    output=PercVector;
end   


end

